@@ -5,22 +5,24 @@
 # Wrapper for fst estimator from hierfstat package
 #
 fstat <- function(x, pop=NULL, fstonly=FALSE){
-    ## misc checks
-    if(!is.genind(x)) stop("x is not a valid genind object")
-    if(!require(hierfstat)) stop("hierfstat package is required. Please install it.")
-    if(x@ploidy != as.integer(2)) stop("not implemented for non-diploid genotypes")
-    checkType(x)
+    cat("\nSorry, hierfstat package has been disabled - this function will be restored in a future release.\n")
+    return(invisible())
+    ## ## misc checks
+    ## if(!is.genind(x)) stop("x is not a valid genind object")
+    ## if(!require(hierfstat)) stop("hierfstat package is required. Please install it.")
+    ## if(x@ploidy != as.integer(2)) stop("not implemented for non-diploid genotypes")
+    ## checkType(x)
 
-    if(is.null(pop)) pop <- x@pop
-    if(is.null(pop)) stop("no pop factor provided")
-    if(length(pop)!=nrow(x@tab)) stop("pop has a wrong length.")
+    ## if(is.null(pop)) pop <- x@pop
+    ## if(is.null(pop)) stop("no pop factor provided")
+    ## if(length(pop)!=nrow(x@tab)) stop("pop has a wrong length.")
 
-    ## computations
-    dat <- genind2hierfstat(x)[,-1]
-    res <- varcomp.glob(levels=data.frame(pop), loci=dat)$F
+    ## ## computations
+    ## dat <- genind2hierfstat(x)[,-1]
+    ## res <- varcomp.glob(levels=data.frame(pop), loci=dat)$F
 
-    if(fstonly) {res <- res[1,1]}
-    return(res)
+    ## if(fstonly) {res <- res[1,1]}
+    ## return(res)
 }
 
 
@@ -69,6 +71,9 @@ pairwise.fst <- function(x, pop=NULL, res.type=c("dist","matrix"), truenames=TRU
     temp <- pop(x)
     levPop <- levels(temp)
     allPairs <- combn(1:length(levPop), 2)
+    if(!is.matrix(allPairs)){
+        allPairs <- matrix(allPairs,nrow=2)
+    }
 
     vecRes <- numeric()
     for(i in 1:ncol(allPairs)){
